==> zio-aws-lightsail_2.12-5.19.7.3-sources.jar: zio/aws/lightsail/model/RelationalDatabaseSnapshot.scala <==
package zio.aws.lightsail.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lightsail.model.primitives.{
  Integer,
  IsoDate,
  NonEmptyString,
  ResourceName
}
import scala.jdk.CollectionConverters._
final case class RelationalDatabaseSnapshot(
    name: Optional[ResourceName] = Optional.Absent,
    arn: Optional[NonEmptyString] = Optional.Absent,
    supportCode: Optional[String] = Optional.Absent,
    createdAt: Optional[IsoDate] = Optional.Absent,
    location: Optional[zio.aws.lightsail.model.ResourceLocation] =
      Optional.Absent,
    resourceType: Optional[zio.aws.lightsail.model.ResourceType] =
      Optional.Absent,
    tags: Optional[Iterable[zio.aws.lightsail.model.Tag]] = Optional.Absent,
    engine: Optional[NonEmptyString] = Optional.Absent,
    engineVersion: Optional[NonEmptyString] = Optional.Absent,
    sizeInGb: Optional[Integer] = Optional.Absent,
    state: Optional[NonEmptyString] = Optional.Absent,
    fromRelationalDatabaseName: Optional[NonEmptyString] = Optional.Absent,
    fromRelationalDatabaseArn: Optional[NonEmptyString] = Optional.Absent,
    fromRelationalDatabaseBundleId: Optional[String] = Optional.Absent,
    fromRelationalDatabaseBlueprintId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot = {
    import RelationalDatabaseSnapshot.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot
      .builder()
      .optionallyWith(
        name.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        arn.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(supportCode.map(value => value: java.lang.String))(
        _.supportCode
      )
      .optionallyWith(createdAt.map(value => IsoDate.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(location.map(value => value.buildAwsValue()))(_.location)
      .optionallyWith(resourceType.map(value => value.unwrap))(_.resourceType)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        engine.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.engine)
      .optionallyWith(
        engineVersion.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.engineVersion)
      .optionallyWith(sizeInGb.map(value => value: java.lang.Integer))(
        _.sizeInGb
      )
      .optionallyWith(
        state.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.state)
      .optionallyWith(
        fromRelationalDatabaseName.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.fromRelationalDatabaseName)
      .optionallyWith(
        fromRelationalDatabaseArn.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.fromRelationalDatabaseArn)
      .optionallyWith(
        fromRelationalDatabaseBundleId.map(value => value: java.lang.String)
      )(_.fromRelationalDatabaseBundleId)
      .optionallyWith(
        fromRelationalDatabaseBlueprintId.map(value => value: java.lang.String)
      )(_.fromRelationalDatabaseBlueprintId)
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.RelationalDatabaseSnapshot.ReadOnly =
    zio.aws.lightsail.model.RelationalDatabaseSnapshot.wrap(buildAwsValue())
}
object RelationalDatabaseSnapshot {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.RelationalDatabaseSnapshot =
      zio.aws.lightsail.model.RelationalDatabaseSnapshot(
        name.map(value => value),
        arn.map(value => value),
        supportCode.map(value => value),
        createdAt.map(value => value),
        location.map(value => value.asEditable),
        resourceType.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        engine.map(value => value),
        engineVersion.map(value => value),
        sizeInGb.map(value => value),
        state.map(value => value),
        fromRelationalDatabaseName.map(value => value),
        fromRelationalDatabaseArn.map(value => value),
        fromRelationalDatabaseBundleId.map(value => value),
        fromRelationalDatabaseBlueprintId.map(value => value)
      )
    def name: Optional[ResourceName]
    def arn: Optional[NonEmptyString]
    def supportCode: Optional[String]
    def createdAt: Optional[IsoDate]
    def location: Optional[zio.aws.lightsail.model.ResourceLocation.ReadOnly]
    def resourceType: Optional[zio.aws.lightsail.model.ResourceType]
    def tags: Optional[List[zio.aws.lightsail.model.Tag.ReadOnly]]
    def engine: Optional[NonEmptyString]
    def engineVersion: Optional[NonEmptyString]
    def sizeInGb: Optional[Integer]
    def state: Optional[NonEmptyString]
    def fromRelationalDatabaseName: Optional[NonEmptyString]
    def fromRelationalDatabaseArn: Optional[NonEmptyString]
    def fromRelationalDatabaseBundleId: Optional[String]
    def fromRelationalDatabaseBlueprintId: Optional[String]
    def getName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("arn", arn)
    def getSupportCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("supportCode", supportCode)
    def getCreatedAt: ZIO[Any, AwsError, IsoDate] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getLocation: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.ResourceLocation.ReadOnly
    ] = AwsError.unwrapOptionField("location", location)
    def getResourceType
        : ZIO[Any, AwsError, zio.aws.lightsail.model.ResourceType] =
      AwsError.unwrapOptionField("resourceType", resourceType)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.lightsail.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getEngine: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("engine", engine)
    def getEngineVersion: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getSizeInGb: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("sizeInGb", sizeInGb)
    def getState: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("state", state)
    def getFromRelationalDatabaseName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "fromRelationalDatabaseName",
        fromRelationalDatabaseName
      )
    def getFromRelationalDatabaseArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "fromRelationalDatabaseArn",
        fromRelationalDatabaseArn
      )
    def getFromRelationalDatabaseBundleId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "fromRelationalDatabaseBundleId",
        fromRelationalDatabaseBundleId
      )
    def getFromRelationalDatabaseBlueprintId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "fromRelationalDatabaseBlueprintId",
        fromRelationalDatabaseBlueprintId
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot
  ) extends zio.aws.lightsail.model.RelationalDatabaseSnapshot.ReadOnly {
    override val name: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.lightsail.model.primitives.ResourceName(value))
    override val arn: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val supportCode: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.supportCode())
      .map(value => value: String)
    override val createdAt: Optional[IsoDate] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.lightsail.model.primitives.IsoDate(value))
    override val location
        : Optional[zio.aws.lightsail.model.ResourceLocation.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.location())
        .map(value => zio.aws.lightsail.model.ResourceLocation.wrap(value))
    override val resourceType: Optional[zio.aws.lightsail.model.ResourceType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resourceType())
        .map(value => zio.aws.lightsail.model.ResourceType.wrap(value))
    override val tags: Optional[List[zio.aws.lightsail.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lightsail.model.Tag.wrap(item)
          }.toList
        )
    override val engine: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.engine())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val engineVersion: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.engineVersion())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val sizeInGb: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.sizeInGb())
      .map(value => value: Integer)
    override val state: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.state())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val fromRelationalDatabaseName: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.fromRelationalDatabaseName())
        .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val fromRelationalDatabaseArn: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.fromRelationalDatabaseArn())
        .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val fromRelationalDatabaseBundleId: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.fromRelationalDatabaseBundleId())
        .map(value => value: String)
    override val fromRelationalDatabaseBlueprintId: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.fromRelationalDatabaseBlueprintId())
        .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot
  ): zio.aws.lightsail.model.RelationalDatabaseSnapshot.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/RelationalDatabaseSnapshot.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.{
  Integer,
  IsoDate,
  NonEmptyString,
  ResourceName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class RelationalDatabaseSnapshot(
    name: Option[ResourceName] = None,
    arn: Option[NonEmptyString] = None,
    supportCode: Option[String] = None,
    createdAt: Option[IsoDate] = None,
    location: Option[zio.aws.lightsail.model.ResourceLocation] = None,
    resourceType: Option[zio.aws.lightsail.model.ResourceType] = None,
    tags: Option[Iterable[zio.aws.lightsail.model.Tag]] = None,
    engine: Option[NonEmptyString] = None,
    engineVersion: Option[NonEmptyString] = None,
    sizeInGb: Option[Integer] = None,
    state: Option[NonEmptyString] = None,
    fromRelationalDatabaseName: Option[NonEmptyString] = None,
    fromRelationalDatabaseArn: Option[NonEmptyString] = None,
    fromRelationalDatabaseBundleId: Option[String] = None,
    fromRelationalDatabaseBlueprintId: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot = {
    import RelationalDatabaseSnapshot.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot
      .builder()
      .optionallyWith(
        name.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        arn.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(supportCode.map(value => value: java.lang.String))(
        _.supportCode
      )
      .optionallyWith(createdAt.map(value => IsoDate.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(location.map(value => value.buildAwsValue()))(_.location)
      .optionallyWith(resourceType.map(value => value.unwrap))(_.resourceType)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        engine.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.engine)
      .optionallyWith(
        engineVersion.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.engineVersion)
      .optionallyWith(
        sizeInGb.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.sizeInGb)
      .optionallyWith(
        state.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.state)
      .optionallyWith(
        fromRelationalDatabaseName.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.fromRelationalDatabaseName)
      .optionallyWith(
        fromRelationalDatabaseArn.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.fromRelationalDatabaseArn)
      .optionallyWith(
        fromRelationalDatabaseBundleId.map(value => value: java.lang.String)
      )(_.fromRelationalDatabaseBundleId)
      .optionallyWith(
        fromRelationalDatabaseBlueprintId.map(value => value: java.lang.String)
      )(_.fromRelationalDatabaseBlueprintId)
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.RelationalDatabaseSnapshot.ReadOnly =
    zio.aws.lightsail.model.RelationalDatabaseSnapshot.wrap(buildAwsValue())
}
object RelationalDatabaseSnapshot {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.RelationalDatabaseSnapshot =
      zio.aws.lightsail.model.RelationalDatabaseSnapshot(
        name.map(value => value),
        arn.map(value => value),
        supportCode.map(value => value),
        createdAt.map(value => value),
        location.map(value => value.asEditable),
        resourceType.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        engine.map(value => value),
        engineVersion.map(value => value),
        sizeInGb.map(value => value),
        state.map(value => value),
        fromRelationalDatabaseName.map(value => value),
        fromRelationalDatabaseArn.map(value => value),
        fromRelationalDatabaseBundleId.map(value => value),
        fromRelationalDatabaseBlueprintId.map(value => value)
      )
    def name: Option[ResourceName]
    def arn: Option[NonEmptyString]
    def supportCode: Option[String]
    def createdAt: Option[IsoDate]
    def location: Option[zio.aws.lightsail.model.ResourceLocation.ReadOnly]
    def resourceType: Option[zio.aws.lightsail.model.ResourceType]
    def tags: Option[List[zio.aws.lightsail.model.Tag.ReadOnly]]
    def engine: Option[NonEmptyString]
    def engineVersion: Option[NonEmptyString]
    def sizeInGb: Option[Integer]
    def state: Option[NonEmptyString]
    def fromRelationalDatabaseName: Option[NonEmptyString]
    def fromRelationalDatabaseArn: Option[NonEmptyString]
    def fromRelationalDatabaseBundleId: Option[String]
    def fromRelationalDatabaseBlueprintId: Option[String]
    def getName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("arn", arn)
    def getSupportCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("supportCode", supportCode)
    def getCreatedAt: ZIO[Any, AwsError, IsoDate] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getLocation: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.ResourceLocation.ReadOnly
    ] = AwsError.unwrapOptionField("location", location)
    def getResourceType
        : ZIO[Any, AwsError, zio.aws.lightsail.model.ResourceType] =
      AwsError.unwrapOptionField("resourceType", resourceType)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.lightsail.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getEngine: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("engine", engine)
    def getEngineVersion: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getSizeInGb: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("sizeInGb", sizeInGb)
    def getState: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("state", state)
    def getFromRelationalDatabaseName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "fromRelationalDatabaseName",
        fromRelationalDatabaseName
      )
    def getFromRelationalDatabaseArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "fromRelationalDatabaseArn",
        fromRelationalDatabaseArn
      )
    def getFromRelationalDatabaseBundleId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "fromRelationalDatabaseBundleId",
        fromRelationalDatabaseBundleId
      )
    def getFromRelationalDatabaseBlueprintId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "fromRelationalDatabaseBlueprintId",
        fromRelationalDatabaseBlueprintId
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot
  ) extends zio.aws.lightsail.model.RelationalDatabaseSnapshot.ReadOnly {
    override val name: Option[ResourceName] = scala
      .Option(impl.name())
      .map(value => zio.aws.lightsail.model.primitives.ResourceName(value))
    override val arn: Option[NonEmptyString] = scala
      .Option(impl.arn())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val supportCode: Option[String] =
      scala.Option(impl.supportCode()).map(value => value: String)
    override val createdAt: Option[IsoDate] = scala
      .Option(impl.createdAt())
      .map(value => zio.aws.lightsail.model.primitives.IsoDate(value))
    override val location
        : Option[zio.aws.lightsail.model.ResourceLocation.ReadOnly] = scala
      .Option(impl.location())
      .map(value => zio.aws.lightsail.model.ResourceLocation.wrap(value))
    override val resourceType: Option[zio.aws.lightsail.model.ResourceType] =
      scala
        .Option(impl.resourceType())
        .map(value => zio.aws.lightsail.model.ResourceType.wrap(value))
    override val tags: Option[List[zio.aws.lightsail.model.Tag.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lightsail.model.Tag.wrap(item)
          }.toList
        )
    override val engine: Option[NonEmptyString] = scala
      .Option(impl.engine())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val engineVersion: Option[NonEmptyString] = scala
      .Option(impl.engineVersion())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val sizeInGb: Option[Integer] = scala
      .Option(impl.sizeInGb())
      .map(value => zio.aws.lightsail.model.primitives.Integer(value))
    override val state: Option[NonEmptyString] = scala
      .Option(impl.state())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val fromRelationalDatabaseName: Option[NonEmptyString] = scala
      .Option(impl.fromRelationalDatabaseName())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val fromRelationalDatabaseArn: Option[NonEmptyString] = scala
      .Option(impl.fromRelationalDatabaseArn())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val fromRelationalDatabaseBundleId: Option[String] = scala
      .Option(impl.fromRelationalDatabaseBundleId())
      .map(value => value: String)
    override val fromRelationalDatabaseBlueprintId: Option[String] = scala
      .Option(impl.fromRelationalDatabaseBlueprintId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.RelationalDatabaseSnapshot
  ): zio.aws.lightsail.model.RelationalDatabaseSnapshot.ReadOnly = new Wrapper(
    impl
  )
}
